@@ -1,5 +1,5 @@
-import typing
 from datetime import datetime
+from typing import Generator
 
 
 class PortsModel:
@@ -152,6 +152,7 @@ class ServerModel:
     server_id : str
     name : str
     user_data : str
+    match_id : str
     game : str
     location : str
     players_online : int
@@ -192,6 +193,7 @@ class ServerModel:
         self.server_id = data["id"]
         self.name = data["name"]
         self.user_data = data["user_data"]
+        self.match_id = data["match_id"]
         self.game = data["game"]
         self.location = data["location"]
         self.players_online = data["players_online"]
@@ -223,19 +225,23 @@ class ServerModel:
         self.added_voice_server = data["added_voice_server"]
         self.duplicate_source_server = data["duplicate_source_server"]
 
-        self.teamspeak = TeamspeakModel(data["teamspeak3_settings"]) \
-            if data["teamspeak3_settings"] else None
-        self.teamfortress = TeamFortressModel(data["teamfortress2_settings"]) \
-            if data["teamfortress2_settings"] else None
-        self.mumble = MumbleModel(data["mumble_settings"]) \
-            if data["mumble_settings"] else None
-        self.csgo = CsgoModel(data["csgo_settings"]) \
-            if data["csgo_settings"] else None
+        self.teamspeak = TeamspeakModel(
+            data["teamspeak3_settings"]
+        ) if data["teamspeak3_settings"] else None
+        self.teamfortress = TeamFortressModel(
+            data["teamfortress2_settings"]
+        ) if data["teamfortress2_settings"] else None
+        self.mumble = MumbleModel(
+            data["mumble_settings"]
+        ) if data["mumble_settings"] else None
+        self.csgo = CsgoModel(
+            data["csgo_settings"]
+        ) if data["csgo_settings"] else None
 
         self.__scheduled_commands = data["scheduled_commands"]
 
-    def scheduled_commands(self) \
-            -> typing.Generator[ScheduledCommandsModel, None, None]:
+    def scheduled_commands(self
+                           ) -> Generator[ScheduledCommandsModel, None, None]:
         """Lists scheduled commands.
 
         Yields
